# xero-python

[![image](https://img.shields.io/pypi/v/xero-python.svg)](https://pypi.python.org/pypi/xero-python)

<!-- [![image](https://img.shields.io/travis/xero-github/xero-python.svg)](https://travis-ci.com/xero-github/xero-python) -->

<!-- [![Documentation Status](https://readthedocs.org/projects/xero-python/badge/?version=latest)](https://xero-python.readthedocs.io/en/latest/?badge=latest) -->

Official Python sdk for Xero API generated by OpenAPI spec for oAuth2

*   Free software: MIT license
<!--  *   Documentation: <https://xero-python.readthedocs.io>. -->

## Features

* XERO API Client with oauth2 token integration.
* Automatic oauth2 token refresh before token expiration.
* Class based interface for Xero API endpoints.
* Model classes used to represent API data.
* Currently Supported API sets:
    * [Accounting API](https://developer.xero.com/documentation/api/api-overview)
* Error handling for ease of use.

## Credits

* This package was created with
[Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
project template.


## Contribution

Please read [contribution](https://github.com/xero-github/xero-python/blob/master/CONTRIBUTING.md) guidelines.
